@@ -2,16 +2,16 @@ use serde::Deserialize;
 use serde::Serialize;
 
 #[derive(Debug, Serialize)]
-pub struct Request<T> {
-	method: String,
+pub struct Request<'a, T> {
+	method: &'a str,
 	tag: u8,
 	pub arguments: T
 }
 
-impl<T> Request<T> {
-	pub fn new(method: impl ToString, tag: u8, arguments: T) -> Self {
+impl<'a, T> Request<'a, T> {
+	pub fn new(method: &'a str, tag: u8, arguments: T) -> Self {
 		Self{
-			method: method.to_string(),
+			method: method,
 			tag,
 			arguments
 		}
